@@ -10,7 +10,7 @@ OptimalLogLi <- rep(0,length(y))
 iterct <- rep(0,length(y))
 
 #create vector of ones
-   if(is.matrix(x)==TRUE) {onevec <- rep(1,length(x[,1]))} else onevec <- rep(1,length(x)) 
+   if(is.matrix(x)==TRUE || is.data.frame(x) == TRUE) {onevec <- rep(1,length(x[,1]))} else onevec <- rep(1,length(x)) 
 
 #create real X matrix, namely where 1st col is vector of 1s to incorporate beta0 effect
    newx <- cbind(onevec,x) 
